"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.onUnhandledError = onUnhandledError;
exports.onUnhandledRejection = onUnhandledRejection;
exports.onBuildOk = onBuildOk;
exports.onBuildError = onBuildError;
exports.onRefresh = onRefresh;
Object.defineProperty(exports, "getErrorByType", {
    enumerable: true,
    get: function() {
        return _getErrorByType.getErrorByType;
    }
});
Object.defineProperty(exports, "getServerError", {
    enumerable: true,
    get: function() {
        return _nodeStackFrames.getServerError;
    }
});
Object.defineProperty(exports, "ReactDevOverlay", {
    enumerable: true,
    get: function() {
        return _reactDevOverlay.default;
    }
});
var _interop_require_default = require("@swc/helpers/lib/_interop_require_default.js").default;
var _errorOverlayReducer = require("./internal/error-overlay-reducer");
var _parseStack = require("./internal/helpers/parseStack");
var _getErrorByType = require("./internal/helpers/getErrorByType");
var _nodeStackFrames = require("./internal/helpers/nodeStackFrames");
var _reactDevOverlay = _interop_require_default(require("./internal/ReactDevOverlay"));
function onUnhandledError(dispatch, ev) {
    const error = ev == null ? void 0 : ev.error;
    if (!error || !(error instanceof Error) || typeof error.stack !== 'string') {
        // A non-error was thrown, we don't have anything to show. :-(
        return;
    }
    if (error.message.match(/(hydration|content does not match|did not match)/i)) {
        error.message += `\n\nSee more info here: https://nextjs.org/docs/messages/react-hydration-error`;
    }
    const e = error;
    dispatch({
        type: _errorOverlayReducer.ACTION_UNHANDLED_ERROR,
        reason: error,
        frames: (0, _parseStack).parseStack(e.stack)
    });
}
function onUnhandledRejection(dispatch, ev) {
    const reason = ev == null ? void 0 : ev.reason;
    if (!reason || !(reason instanceof Error) || typeof reason.stack !== 'string') {
        // A non-error was thrown, we don't have anything to show. :-(
        return;
    }
    const e = reason;
    dispatch({
        type: _errorOverlayReducer.ACTION_UNHANDLED_REJECTION,
        reason: reason,
        frames: (0, _parseStack).parseStack(e.stack)
    });
}
function onBuildOk(dispatch) {
    dispatch({
        type: _errorOverlayReducer.ACTION_BUILD_OK
    });
}
function onBuildError(dispatch, message) {
    dispatch({
        type: _errorOverlayReducer.ACTION_BUILD_ERROR,
        message
    });
}
function onRefresh(dispatch) {
    dispatch({
        type: _errorOverlayReducer.ACTION_REFRESH
    });
}

if ((typeof exports.default === 'function' || (typeof exports.default === 'object' && exports.default !== null)) && typeof exports.default.__esModule === 'undefined') {
  Object.defineProperty(exports.default, '__esModule', { value: true });
  Object.assign(exports.default, exports);
  module.exports = exports.default;
}

//# sourceMappingURL=client.js.map